import unittest
import json

__unittest = True


class EmodpyImportTest(unittest.TestCase):
    def setUp(self) -> None:
        self.expected_items = None
        self.found_items = None
        pass

    def verify_expected_items_present(self, namespace):
        self.found_items = dir(namespace)
        for item in self.expected_items:
            self.assertIn(
                item,
                self.found_items
            )

    def tearDown(self) -> None:
        pass

    def test_package_emodpy(self):
        import emodpy
        self.expected_items = [
            "bamboo_api_utils",
            "emod_campaign"
        ]
        self.verify_expected_items_present(namespace=emodpy)

    def test_module_bamboo_api_utils(self):
        import emodpy.bamboo_api_utils as b_a_u
        self.expected_items = [
            "BambooConnection",
            "BuildInfo",
            "BuildArtifacts",
            "BuildPlans"
        ]
        self.verify_expected_items_present(namespace=b_a_u)

        test_bamboo_connection = b_a_u.BambooConnection()
        self.assertIn("bamboo", test_bamboo_connection.server.lower())
        self.assertIsNotNone(test_bamboo_connection.session_cookie)
        pass

    def test_module_emod_campaign(self):
        import emodpy.emod_campaign as e_c
        self.expected_items = [
            "EMODCampaign"
        ]
        self.verify_expected_items_present(namespace=e_c)

        specified_campaign_name = "BobbyMcGee"
        test_campaign_default = e_c.EMODCampaign(use_defaults=True)
        self.assertIsNotNone(test_campaign_default)
        test_camapaign_string = test_campaign_default.json
        test_campaign_dict = json.loads(test_camapaign_string)
        observed_campaign_name = test_campaign_dict["Campaign_Name"]
        self.assertNotEqual(specified_campaign_name, observed_campaign_name)
        observed_use_defaults = test_campaign_dict["Use_Defaults"]
        self.assertTrue(observed_use_defaults)

        test_campaign_specified = e_c.EMODCampaign(
            name=specified_campaign_name,
            use_defaults=False
        )
        self.assertIsNotNone(test_campaign_specified)
        test_campaign_specified_string = test_campaign_specified.json
        test_campaign_specified_dict = json.loads(test_campaign_specified_string)

        self.assertEqual(specified_campaign_name, test_campaign_specified_dict["Campaign_Name"])
        self.assertFalse(test_campaign_specified_dict["Use_Defaults"])
        pass
